package com.koobietech.eas.controller;

import com.github.pagehelper.PageHelper;
import com.koobietech.eas.common.constant.Disabled;
import com.koobietech.eas.common.result.JsonPageResult;
import com.koobietech.eas.common.result.JsonResult;
import com.koobietech.eas.common.result.PageData;
import com.koobietech.eas.mbg.model.EasEduClassroom;
import com.koobietech.eas.service.EasEduClassroomService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

@RestController
@Tag(name = "教室控制器")
public class EasEduClassroomController {

    @Resource
    EasEduClassroomService easEduClassroomService;

    /**
     * 添加教室教室信息
     * @param easEduClassroom
     * @return
     */
    @PostMapping(value = "/addClassroom")
    @Operation(summary = "添加教室",description = "用于添加教室")
    public JsonResult addClassroom(@RequestBody EasEduClassroom easEduClassroom){
        int addClassroom_i = easEduClassroomService.addClassroom(easEduClassroom);
        System.out.println(addClassroom_i);
        return JsonResult.ok("添加成功!");
    }

    /**
     * 修改教室信息
     * @param easEduClassroom
     * @return
     */
    @PutMapping(value = "/updateClassroom")
    @Operation(summary = "修改教室信息",description = "用于修改教室信息")
    public JsonResult updateClassroom(@RequestBody EasEduClassroom easEduClassroom){
        int updateClassroom_i = easEduClassroomService.updateClassroom(easEduClassroom);
        if (updateClassroom_i > 0){
            return JsonResult.ok("修改成功!");
        }else {
            return JsonResult.fail("修改失败!");
        }
    }

    /**
     * 删除教室信息
     * @param id
     * @return
     */
    @DeleteMapping(value = "/deleteClassroom/{id}")
    @Operation(summary = "删除教室信息",description = "用于删除教室信息")
    public JsonResult deleteClassroom(@PathVariable int id){
        int deleteClassroom_i = easEduClassroomService.deleteClassroom(id);
        if (deleteClassroom_i > 0){
            return JsonResult.ok("删除成功!");
        }else {
            return JsonResult.fail("删除失败!");
        }
    }

    /**
     * 根据 id 查询教室信息
     * @param id
     * @return
     */
    @GetMapping(value = "/selectClassroomById")
    @Operation(summary = "根据 id 查询教室信息",description = "用于根据 id 删除教室信息")
    public JsonResult selectClassroomById(Integer id){
        EasEduClassroom easEduClassroom = easEduClassroomService.selectClassroomById(id);
        System.out.println(
                Disabled.valueOf(easEduClassroom.getDisabled())
        );
        return JsonResult.data( easEduClassroom );
    }

    /**
     * 查询所有的教室信息
     * @return
     */
    @GetMapping(value = "/selectAllClassroom")
    @Operation(summary = "查询所有的教室信息",description = "用于查询所有的教室信息")
    public JsonResult selectAllClassroom(){
        List<EasEduClassroom> easEduClassrooms = easEduClassroomService.selectAllClassroom();
        return JsonResult.data(easEduClassrooms);
    }


    /**
     * 根据条件查询课程
     * @param easEduClassroom
     * @param pageNum
     * @param pageSize
     * @return
     */
    @PostMapping(value = "/selectClassroomByExample")
    @Operation(summary = "条件查询教室信息",description = "用于根据条件查询教室信息")
    public JsonPageResult selectClassroomByExample(@RequestBody EasEduClassroom easEduClassroom,
                                                     @RequestParam Integer pageNum,@RequestParam Integer pageSize){
        PageHelper.startPage(pageNum,pageSize);
        PageData pageData = easEduClassroomService.selectClassroomByExample(easEduClassroom);
        return JsonPageResult.data(pageData);
    }
}
